/*
   Copyright (C) 1994,96,2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#include "priv.h"
#include "trivfs_fs_S.h"
#include <string.h>
#include <unistd.h>

kern_return_t
trivfs_S_file_statfs (struct trivfs_protid *cred,
		      mach_port_t reply, mach_msg_type_name_t reply_type,
		      struct statfs *stb)
{
  if (!trivfs_fsid)
    trivfs_fsid = getpid();

  memset (stb, 0, sizeof(struct statfs));
  stb->f_type = trivfs_fstype;
  stb->f_fsid = trivfs_fsid;

  return 0;
}
